      PROGRAM savgwe090 
c
c  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
c  *              P R O G R A N :  S A V G                             *
c  *                                                                   *
c  *                   (S) TRESS    (AV) ERA  (G)  E                   *
c  *   FOR  (EDGE) stresses in a (W)oven "0" [0/90]s laminate for      *
c  * mechanical (MECH) out-of-plane & temperature (THERM) change loads *
c  *                                                                   *
c  *     CALCULATES THE AVERAGE STRESS ALONG A SET OF ELEMENTS         *
c  *                                                                   *
c  *      1. SIGMA-Z & SIGMA-HZ THRU THE LAMINATE AT Y/B=0.9961        *
c  *         Results for plotting: data1.dat                           *
c  *                                                                   *
c  *      2. SIGMA-Z ALONG Y/B NEAR THE STRESS FREE EDGE AT THE        *
c  *         LAMINATE MIDPLANE AND AT THE 0/90 INTERFACE               *
c  *         Results for plotting: data2.dat                           *
c  *                                                                   *
c-----------------------------------------------------------------------
c        1         2         3         4         5         6         7          
c23456789012345678901234567890123456789012345678901234567890123456789012
c-----------------------------------------------------------------------
c  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
c
      DIMENSION SHm(2044),SZm(2044),SHZm(2044)
      DIMENSION SHt(2044),SZt(2044),SHZt(2044)
      dimension esavgz(2,95),esavghz(2,95)
      DIMENSION SAZ(2,34),SAZM(2,34),SAZT(2,34) 
      dimension ydb(34),zdh(95)
C
C  OPEN FILES
C
      OPEN(4,FILE='lfemiwe090mechstress.out',STATUS='OLD',ERR=888)
      OPEN(5,FILE='lfemiwe090thermstress.out',STATUS='OLD',ERR=888)
      OPEN(6,FILE='savgwe090stress.out',STATUS='UNKNOWN',ERR=888)
      OPEN(7,FILE='data1.dat',STATUS='UNKNOWN',ERR=888)
      OPEN(8,FILE='data2.dat',STATUS='UNKNOWN',ERR=888)
      OPEN(9,FILE='data3.dat',STATUS='UNKNOWN',ERR=888)
C
C  DEFINE PARAMETERS: No. of elements, ne & out-of-plane strain, ex
C
      NE=2044
      ex=0.01
C
C  READ IN ELEMENTAL STRESSES  "m"->"MECH"  "t"->"THERM"
C
      DO 100 K=1,NE 
      READ(4,10)SHm(K),SZm(K),SHZm(K)
  100 READ(5,10)SHt(K),SZt(K),SHZt(K)
   10 FORMAT(3E11.4)
c-----------------------------------------------------------------
c-----------------------------------------------------------------
C
C EDGE STRESSES AVERAGED FROM TOP SURFACE TO MIDPLANE, Y/B=0.9961
C
c   ------------------------------------------------------------ 
C   --- THRU THE FIRST REGION: Top surface to 0/90 interface ---
C
      I1=337
      DO 200 I=1,47 
      J=I1+2*(I-1)
      ESAVGZ(1,i)=(SZm(J)+SZm(J+1)+SZm(J+2)+SZm(J+3))/4.
      ESAVGZ(2,i)=ESAVGZ(1,i)+(SZt(J)+SZt(J+1)+SZt(J+2)+SZt(J+3))/4.
      ESAVGHZ(1,i)=(SHZm(J)+SHZm(J+1)+SHZm(J+2)+SHZm(J+3))/4.
      ESAVGHZ(2,i)=ESAVGHZ(1,i)
     *             +(SHZt(J)+SHZt(J+1)+SHZt(J+2)+SHZt(J+3))/4.
      ZDH(i)=1.0-0.125*I/12.0
  200 WRITE(6,20)I,zdh(i),ESAVGZ(1,i),ESAVGHZ(1,i)
     *                   ,ESAVGZ(2,i),ESAVGHZ(2,i)
   20 FORMAT(1X,' I=',I2,' Z/H=',F6.4,' SIGZm=',E10.3,' SIGHZm=',E10.3  
     *                           ,' SIGZm+t=',E10.3,' SIGHZm+t=',E10.3)
C
c   -----------------------------
C   --- AT THE 0/90 INTERFACE ---
C
      I=48
      I1=431
      I2=661
      ESAVGZ(1,i)=(SZm(I1)+SZm(I1+1)+SZm(I2)+SZm(I2+1))/4. 
      ESAVGZ(2,i)=ESAVGZ(1,i)+(SZt(I1)+SZt(I1+1)+SZt(I2)+SZt(I2+1))/4. 
      ESAVGHZ(1,i)=(SHZm(I1)+SHZm(I1+1)+SHZm(I2)+SHZm(I2+1))/4.
      ESAVGHZ(2,i)=ESAVGHZ(1,i)
     *             +(SHZt(I1)+SHZt(I1+1)+SHZt(I2)+SHZt(I2+1))/4.
      ZDH(i)=1.0-6.0/12.0
      WRITE(6,20)I,zdh(i),ESAVGZ(1,i),ESAVGHZ(1,i)
     *                   ,ESAVGZ(2,i),ESAVGHZ(2,i)
C
c   ---------------------------------------------------------- 
C   --- THRU THE SECOND REGION: 0/90 interface to midplane ---
C
      I1=661
      DO 300 I=49,95
      J=I1+2*(I-49) 
      ESAVGZ(1,i)=(SZm(J)+SZm(J+1)+SZm(J+2)+SZm(J+3))/4.
      ESAVGZ(2,i)=ESAVGZ(1,i)+(SZt(J)+SZt(J+1)+SZt(J+2)+SZt(J+3))/4.
      ESAVGHZ(1,i)=(SHZm(J)+SHZm(J+1)+SHZm(J+2)+SHZm(J+3))/4.
      ESAVGHZ(2,i)=ESAVGHZ(1,i)
     *             +(SHZt(J)+SHZt(J+1)+SHZt(J+2)+SHZt(J+3))/4.
      ZDH(i)=1.0-0.125*I/12.0
  300 WRITE(6,20)I,zdh(i),ESAVGZ(1,i),ESAVGHZ(1,i)
     *                   ,ESAVGZ(2,i),ESAVGHZ(2,i) 
c-----------------------------------------------------------------
c-----------------------------------------------------------------
c  
c   AVERAGE SIGMA-Z STRESESS ALONG THE TOP SURFACE (SAZT), AT 
c   THE 0/90 INTERFACE (SAZ), AND ALONG THE MIDPLANE (SAZM).
c
c   NORMALIZE SIGMA-Z WITH RESPECT TO OUT-OF-PLANE STRAIN, ex
C
c   -------------------------------------------------------
C   --- THE FIRST two REGIONs near the stress free edge --- 
C
C   COORDINATE WIDTH RATIO
      YDB(34)=0.9961 
      YDB(33)=0.9922 
      YDB(32)=15.675/16.0
      YDB(31)=15.25/16.0
      YDB(30)=14.75/16.0
      YDB(29)=14.25/16.0
c
c   Along the 0/90 interface
c
c                          MECH
      SAZ(1,34)=((SZm(431)+SZm(432)+SZm(661)+SZm(662))/4.)/ex 
      SAZ(1,33)=((SZm(336)+SZm(432)+SZm(661)+SZm(589))/4.)/ex 
      SAZ(1,32)=((SZm(263)+SZm(493))/2.)/ex
      SAZ(1,31)=((SZm(166)+SZm(433))/2.)/ex
      SAZ(1,30)=((SZm(53)+ SZm(59))/2.)/ex
      SAZ(1,29)=((SZm(49)+ SZm(55))/2.)/ex
c
c                       MECH+THERM
      SAZ(2,34)=SAZ(1,34)+((SZt(431)+SZt(432)+SZt(661)+SZt(662))/4.)/ex 
      SAZ(2,33)=SAZ(1,33)+((SZt(336)+SZt(432)+SZt(661)+SZt(589))/4.)/ex 
      SAZ(2,32)=SAZ(1,32)+((SZt(263)+SZt(493))/2.)/ex
      SAZ(2,31)=SAZ(1,31)+((SZt(166)+SZt(433))/2.)/ex
      SAZ(2,30)=SAZ(1,30)+((SZt(53)+ SZt(59))/2.)/ex
      SAZ(2,29)=SAZ(1,20)+((SZt(49)+ SZt(55))/2.)/ex
C
C    ALONG THE MIDPLANE
C
c                   MECH
      SAZM(1,34)=((SZm(756)+SZm(755))/2.)/ex
      SAZM(1,33)=((SZm(660)+SZm(756))/2.)/ex
      SAZM(1,32)= (SZm(587))/ex
      SAZM(1,31)= (SZm(490))/ex
      SAZM(1,30)= (SZm(107))/ex
      SAZM(1,29)= (SZm(103))/ex
c
c                MECH+THERM
      SAZM(2,34)=SAZM(1,34)+((SZt(756)+SZt(755))/2.)/ex
      SAZM(2,33)=SAZM(1,33)+((SZt(660)+SZt(756))/2.)/ex
      SAZM(2,32)=SAZM(1,32)+ (SZt(587))/ex
      SAZM(2,31)=SAZM(1,31)+ (SZt(490))/ex
      SAZM(2,30)=SAZM(1,30)+ (SZt(107))/ex
      SAZM(2,29)=SAZM(1,29)+ (SZt(103))/ex
C
c    Along the top surface
c
c                  MECH
      SAZT(1,34)=((SZm(337)+SZm(338))/2.)/ex
      SAZT(1,33)=((SZm(265)+SZm(337))/2.)/ex
      SAZT(1,32)= (SZm(169))/ex
      SAZT(1,31)= (SZm(109))/ex
      SAZT(1,30)= (SZm(5))/ex
      SAZT(1,29)= (SZm(1))/ex
c
c               MECH+THERM
      SAZT(2,34)=SAZT(1,34)+((SZt(337)+SZt(338))/2.)/ex
      SAZT(2,33)=SAZT(1,33)+((SZt(265)+SZt(337))/2.)/ex
      SAZT(2,32)=SAZT(1,32)+ (SZt(169))/ex
      SAZT(2,31)=SAZT(1,31)+ (SZt(109))/ex
      SAZT(2,30)=SAZT(1,30)+ (SZt(5))/ex
      SAZT(2,29)=SAZT(1,29)+ (SZt(1))/ex
c
c   ------------------------------
c   --- In the interior region ---
c
c    Along the 0/90 interface
      I1=1399
      I2=1509
      Y=13.75
      DO 350 I=1,28 
      YDB(29-I)=Y/16.0
      Y=Y-0.5
      J=I1-4*(I-1)
      K=I2-4*(I-1)
      SAZ(1,29-I)=((SZm(J)+SZm(K))/2.)/ex
  350 SAZ(2,29-I)=SAZ(1,29-I)+((SZt(J)+SZt(K))/2.)/ex
c
c    Along the midplane
      I1=2043
      DO 360 I=1,28 
      J=I1-4*(I-1)
      SAZM(1,29-I)=(SZm(J))/ex
  360 SAZM(2,29-I)=SAZM(1,29-I)+(SZt(J))/ex
c
c    Along the top surface
      I1=865
      DO 370 I=1,28 
      J=I1-4*(I-1)
      SAZT(1,29-I)=(SZm(J))/ex
  370 SAZT(1,29-I)=SAZT(1,29-I)+(SZt(J))/ex
c
c ------------------------------------------------------------------
c ------------------------------------------------------------------
c   Write results to output file
c
      write(6,41)
   41 format(' -----------  MECH  ----------')
      DO 400 J=1,34 
  400 WRITE(6,40)J,YDB(J),SAZ(1,J),SAZM(1,J),SAZT(1,J)
   40 FORMAT(1X,' J=',I2,' Y/B=',F6.4,' SIGZ=',E10.3,' SIGZM=',E10.3
     *,' SAZT=',E10.3)
C
      write(6,42)
   42 format(' -------  MECH+THERM  --------')
      DO 402 J=1,34 
  402 WRITE(6,43)J,YDB(J),SAZ(2,J),SAZM(2,J),SAZT(2,J)
   43 FORMAT(1X,' J=',I2,' Y/B=',F6.4,' SIGZ=',E10.3,' SIGZM=',E10.3
     *,' SAZT=',E10.3)
c
c Write results to files for plotting
c
      do 500 j=1,95
      write(7,50)zdh(j),esavgz(1,j),esavgz(2,j)
  500 write(8,50)zdh(j),esavghz(1,j),esavghz(2,j)
      do 501 j=1,34
  501 write(9,50)ydb(j),sazm(1,j),sazm(2,j)
   50 format(3(1x,e11.4))
C
  888 STOP
      END 
